@@ -32,16 +32,19 @@ class Option(object):
         return values
 
 
-def pytest_generate_tests(metafunc):
-    if "option" in metafunc.fixturenames:
-        metafunc.addcall(id="default",
-                         funcargs={'option': Option(verbose=False)})
-        metafunc.addcall(id="verbose",
-                         funcargs={'option': Option(verbose=True)})
-        metafunc.addcall(id="quiet",
-                         funcargs={'option': Option(verbose=-1)})
-        metafunc.addcall(id="fulltrace",
-                         funcargs={'option': Option(fulltrace=True)})
+@pytest.fixture(params=[
+    Option(verbose=False),
+    Option(verbose=True),
+    Option(verbose=-1),
+    Option(fulltrace=True),
+], ids=[
+    "default",
+    "verbose",
+    "quiet",
+    "fulltrace",
+])
+def option(request):
+    return request.param
 
 
 @pytest.mark.parametrize('input,expected', [
@@ -431,11 +434,36 @@ class TestTerminalFunctional(object):
                                       )
         result = testdir.runpytest("-k", "test_two:", testpath)
         result.stdout.fnmatch_lines([
+            "collected 3 items / 1 deselected",
             "*test_deselected.py ..*",
-            "=* 1 test*deselected *=",
         ])
         assert result.ret == 0
 
+    def test_show_deselected_items_using_markexpr_before_test_execution(
+            self, testdir):
+        testdir.makepyfile("""
+            import pytest
+
+            @pytest.mark.foo
+            def test_foobar():
+                pass
+
+            @pytest.mark.bar
+            def test_bar():
+                pass
+
+            def test_pass():
+                pass
+        """)
+        result = testdir.runpytest('-m', 'not foo')
+        result.stdout.fnmatch_lines([
+            "collected 3 items / 1 deselected",
+            "*test_show_des*.py ..*",
+            "*= 2 passed, 1 deselected in * =*",
+        ])
+        assert "= 1 deselected =" not in result.stdout.str()
+        assert result.ret == 0
+
     def test_no_skip_summary_if_failure(self, testdir):
         testdir.makepyfile("""
             import pytest
@@ -657,10 +685,12 @@ def test_color_yes_collection_on_non_atty(testdir, verbose):
 
 
 def test_getreportopt():
-    class config(object):
-        class option(object):
+    class Config(object):
+        class Option(object):
             reportchars = ""
             disable_warnings = True
+        option = Option()
+    config = Config()
 
     config.option.reportchars = "sf"
     assert getreportopt(config) == "sf"
@@ -823,6 +853,51 @@ def pytest_report_header(config, startdir):
             str(testdir.tmpdir),
         ])
 
+    def test_show_capture(self, testdir):
+        testdir.makepyfile("""
+            import sys
+            import logging
+            def test_one():
+                sys.stdout.write('!This is stdout!')
+                sys.stderr.write('!This is stderr!')
+                logging.warning('!This is a warning log msg!')
+                assert False, 'Something failed'
+        """)
+
+        result = testdir.runpytest("--tb=short")
+        result.stdout.fnmatch_lines(["!This is stdout!",
+                                     "!This is stderr!",
+                                     "*WARNING*!This is a warning log msg!"])
+
+        result = testdir.runpytest("--show-capture=all", "--tb=short")
+        result.stdout.fnmatch_lines(["!This is stdout!",
+                                     "!This is stderr!",
+                                     "*WARNING*!This is a warning log msg!"])
+
+        stdout = testdir.runpytest(
+            "--show-capture=stdout", "--tb=short").stdout.str()
+        assert "!This is stderr!" not in stdout
+        assert "!This is stdout!" in stdout
+        assert "!This is a warning log msg!" not in stdout
+
+        stdout = testdir.runpytest(
+            "--show-capture=stderr", "--tb=short").stdout.str()
+        assert "!This is stdout!" not in stdout
+        assert "!This is stderr!" in stdout
+        assert "!This is a warning log msg!" not in stdout
+
+        stdout = testdir.runpytest(
+            "--show-capture=log", "--tb=short").stdout.str()
+        assert "!This is stdout!" not in stdout
+        assert "!This is stderr!" not in stdout
+        assert "!This is a warning log msg!" in stdout
+
+        stdout = testdir.runpytest(
+            "--show-capture=no", "--tb=short").stdout.str()
+        assert "!This is stdout!" not in stdout
+        assert "!This is stderr!" not in stdout
+        assert "!This is a warning log msg!" not in stdout
+
 
 @pytest.mark.xfail("not hasattr(os, 'dup')")
 def test_fdopen_kept_alive_issue124(testdir):
@@ -1046,6 +1121,9 @@ class TestProgress(object):
             r'test_foobar.py \.{5}',
         ])
 
+        output = testdir.runpytest('--capture=no')
+        assert "%]" not in output.stdout.str()
+
 
 class TestProgressWithTeardown(object):
     """Ensure we show the correct percentages for tests that fail during teardown (#3088)"""
